==> tetra_model_zoo-0.1.4-py3-none-any.whl: tetra_model_zoo/models/_shared/detr/model.py <==
from __future__ import annotations

from typing import Tuple

import torch
import torch.nn as nn
from transformers import DetrForObjectDetection

from tetra_model_zoo.utils.input_spec import InputSpec

MODEL_ID = __name__.split(".")[-2]
MODEL_ASSET_VERSION = 1


class DETR(torch.nn.Module):
    """Exportable DETR model, end-to-end."""

    def __init__(self, model: nn.Module) -> None:
        super().__init__()
        self.model = model

    @staticmethod
    def from_pretrained(ckpt_name: str):
        model = DetrForObjectDetection.from_pretrained(ckpt_name)
        model.eval()
        return DETR(model)

    def forward(
        self, image: torch.Tensor, mask: torch.Tensor
    ) -> Tuple[torch.Tensor, torch.Tensor]:
        """
        Run DETR on `image` and `mask`, and produce high quality detection results.

        Parameters:
            image: Image tensor to run detection on.
            mask: This represents the padding mask. True if padding was applied on that pixel else False.

        Returns:
            predictions: Tuple of tensors (logits and coordinates)
               Shape of logit tensor: [1, 100 (number of predictions), 92 (number of classes)]
               Shape of coordinates: [1, 100, 4]

        """
        predictions = self.model(image, mask, return_dict=False)
        return predictions

    def get_input_spec(
        self,
        image_size: tuple[int, int] = (480, 480),
        batch_size: int = 1,
        num_channels: int = 3,
    ) -> InputSpec:
        """
        Returns the input specification (name -> (shape, type). This can be
        used to submit profiling job on TetraHub.
        """
        if isinstance(image_size, int):
            image_size = (image_size, image_size)
        return {
            "image": ((batch_size, num_channels, *image_size), "float32"),
            "mask": ((batch_size, *image_size), "float32"),
        }

==> tetra_model_zoo-0.1.5-py3-none-any.whl: tetra_model_zoo/models/_shared/detr/model.py <==
from __future__ import annotations

from typing import List, Tuple

import torch
import torch.nn as nn
from transformers import DetrForObjectDetection

import tetra_hub as hub
from tetra_model_zoo.utils.input_spec import InputSpec
from tetra_model_zoo.utils.zoo_base_class import DEFAULT_EXPORT_DEVICES, TetraZooModel

MODEL_ID = __name__.split(".")[-2]
MODEL_ASSET_VERSION = 1


class DETR(TetraZooModel):
    """Exportable DETR model, end-to-end."""

    def __init__(self, model: nn.Module) -> None:
        super().__init__()
        self.model = model

    @classmethod
    def from_pretrained(cls, ckpt_name: str):
        model = DetrForObjectDetection.from_pretrained(ckpt_name)
        model.eval()
        return cls(model)

    def export(
        self,
        input_spec: InputSpec | None = None,
        devices: List[hub.Device] | List[str] = DEFAULT_EXPORT_DEVICES,
    ):
        return super().export(input_spec, devices, "--enable_mlpackage")

    def forward(
        self, image: torch.Tensor, mask: torch.Tensor
    ) -> Tuple[torch.Tensor, torch.Tensor]:
        """
        Run DETR on `image` and `mask`, and produce high quality detection results.

        Parameters:
            image: Image tensor to run detection on.
            mask: This represents the padding mask. True if padding was applied on that pixel else False.

        Returns:
            predictions: Tuple of tensors (logits and coordinates)
               Shape of logit tensor: [1, 100 (number of predictions), 92 (number of classes)]
               Shape of coordinates: [1, 100, 4]

        """
        predictions = self.model(image, mask, return_dict=False)
        return predictions

    def get_input_spec(
        self,
        batch_size: int = 1,
        num_channels: int = 3,
        x: int = 480,
        y: int = 480,
    ) -> InputSpec:
        """
        Returns the input specification (name -> (shape, type). This can be
        used to submit profiling job on TetraHub.
        """
        return {
            "image": ((batch_size, num_channels, x, y), "float32"),
            "mask": ((batch_size, x, y), "float32"),
        }
